pub enum CompiledExpr {
Not(Box<CompiledExpr>),
Union(Box<CompiledExpr>, Box<CompiledExpr>),
Intersection(Box<CompiledExpr>, Box<CompiledExpr>),
Set(FiltersetLeaf),
}Variants
Not(Box<CompiledExpr>)
Accepts every test not in the given expression
Union(Box<CompiledExpr>, Box<CompiledExpr>)
Accepts every test in either given expression
Intersection(Box<CompiledExpr>, Box<CompiledExpr>)
Accepts every test in both given expressions
Set(FiltersetLeaf)
Accepts every test in a set
Implementations
Sourceimpl CompiledExpr
impl CompiledExpr
Sourcepub fn matches_binary(
&self,
query: &BinaryQuery<'_>,
cx: &EvalContext<'_>,
) -> Option<bool>
pub fn matches_binary( &self, query: &BinaryQuery<'_>, cx: &EvalContext<'_>, ) -> Option<bool>
Returns a value indicating if the given binary is accepted by this filterset.
The value is:
Some(true)if this binary is definitely accepted by this filterset.Some(false)if this binary is definitely not accepted.Noneif this binary might or might not be accepted.
Sourcepub fn matches_test(&self, query: &TestQuery<'_>, cx: &EvalContext<'_>) -> bool
pub fn matches_test(&self, query: &TestQuery<'_>, cx: &EvalContext<'_>) -> bool
Returns true if the given test is accepted by this filterset.
If a group() predicate is encountered, this method panics.
Only use this for expressions that are guaranteed group-free
(i.e. compiled with any FiltersetKind other than
FiltersetKind::Test, or Test expressions where
has_group_matchers returns false).
Sourcepub fn matches_test_with_groups(
&self,
query: &TestQuery<'_>,
cx: &EvalContext<'_>,
groups: &dyn GroupLookup,
) -> bool
pub fn matches_test_with_groups( &self, query: &TestQuery<'_>, cx: &EvalContext<'_>, groups: &dyn GroupLookup, ) -> bool
Returns true if the given test is accepted by this filterset,
resolving group() predicates via the provided lookup.
Use this for FiltersetKind::Test expressions that contain
group() predicates.
Sourcepub fn has_group_matchers(&self) -> bool
pub fn has_group_matchers(&self) -> bool
Returns true if this expression contains any group() predicates.