Filterset

Struct Filterset 

pub struct Filterset {
    pub input: String,
    pub parsed: ParsedExpr,
    pub compiled: CompiledExpr,
}
A filterset that has been parsed and compiled.

Used to filter tests to run.

Fields

input: String

The raw expression passed in.

parsed: ParsedExpr

The parsed-but-not-compiled expression.

compiled: CompiledExpr

The compiled expression.

Implementations

Source

impl Filterset

pub fn parse( input: String, cx: &ParseContext<'_>, kind: FiltersetKind, known_groups: &KnownGroups, ) -> Result<Self, FiltersetParseErrors>

Parse a filterset.

pub fn matches_binary( &self, query: &BinaryQuery<'_>, cx: &EvalContext<'_>, ) -> Option<bool>

Returns a value indicating if the given binary is accepted by this filterset.

The value is:

  • Some(true) if this binary is definitely accepted by this filterset.
  • Some(false) if this binary is definitely not accepted.
  • None if this binary might or might not be accepted.
pub fn matches_test(&self, query: &TestQuery<'_>, cx: &EvalContext<'_>) -> bool

Returns true if the given test is accepted by this filterset.

Panics if a group() predicate is encountered. See CompiledExpr::matches_test for details.

pub fn matches_test_with_groups( &self, query: &TestQuery<'_>, cx: &EvalContext<'_>, groups: &dyn GroupLookup, ) -> bool

Returns true if the given test is accepted by this filterset, resolving group() predicates via the provided lookup.

See CompiledExpr::matches_test_with_groups for details.

pub fn needs_deps(raw_expr: &str) -> bool

Returns true if the given expression needs dependencies information to work