GroupLookup

Trait GroupLookup 

pub trait GroupLookup: Debug {
    // Required method
    fn is_member_test(
        &self,
        test: &TestQuery<'_>,
        matcher: &NameMatcher,
    ) -> bool;
}
Trait for looking up test group membership during filterset evaluation.

Implemented in nextest-runner and passed to CompiledExpr::matches_test_with_groups to resolve group() predicates.

Required Methods

fn is_member_test(&self, test: &TestQuery<'_>, matcher: &NameMatcher) -> bool

Returns true if the given test is a member of a group matching the provided name matcher.

Implementors