#[non_exhaustive]pub enum ParseSingleError {
Show 24 variants
InvalidRegex {
span: SourceSpan,
message: String,
},
InvalidGlob {
span: SourceSpan,
error: GlobConstructError,
},
BannedPredicate {
kind: FiltersetKind,
span: SourceSpan,
reason: BannedPredicateReason,
},
InvalidRegexWithoutMessage(SourceSpan),
ExpectedCloseRegex(SourceSpan),
InvalidOrOperator(SourceSpan),
InvalidAndOperator(SourceSpan),
UnexpectedArgument(SourceSpan),
UnexpectedComma(SourceSpan),
InvalidString(SourceSpan),
ExpectedOpenParenthesis(SourceSpan),
ExpectedCloseParenthesis(SourceSpan),
InvalidEscapeCharacter(SourceSpan),
ExpectedExpr(SourceSpan),
ExprFoundBinaryOp {
op: &'static str,
suggest: &'static str,
span: SourceSpan,
},
ExprFoundUnaryOp {
op: &'static str,
suggest: &'static str,
span: SourceSpan,
},
ExpectedEndOfExpression(SourceSpan),
NoPackageMatch(SourceSpan),
NoGroupMatch(SourceSpan),
NoBinaryIdMatch(SourceSpan),
NoBinaryNameMatch(SourceSpan),
InvalidPlatformArgument(SourceSpan),
UnsupportedExpression(SourceSpan),
Unknown,
}Expand description
An individual error that occurred while parsing a filterset.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidRegex
An invalid regex was encountered.
Fields
span: SourceSpanThe part of the input that failed.
InvalidGlob
An invalid glob pattern was encountered.
Fields
span: SourceSpanThe part of the input that failed.
error: GlobConstructErrorThe underlying error.
BannedPredicate
A banned predicate was encountered.
Fields
kind: FiltersetKindThe kind of expression.
span: SourceSpanThe span of the banned predicate.
reason: BannedPredicateReasonThe reason why the predicate is banned.
InvalidRegexWithoutMessage(SourceSpan)
An invalid regex was encountered but we couldn’t determine a better error message.
ExpectedCloseRegex(SourceSpan)
A regex string was not closed.
InvalidOrOperator(SourceSpan)
An unexpected OR operator was found.
InvalidAndOperator(SourceSpan)
An unexpected AND operator was found.
UnexpectedArgument(SourceSpan)
An unexpected argument was found.
UnexpectedComma(SourceSpan)
An unexpected comma was found.
InvalidString(SourceSpan)
An invalid string was found.
ExpectedOpenParenthesis(SourceSpan)
An open parenthesis ( was expected but not found.
ExpectedCloseParenthesis(SourceSpan)
A close parenthesis ) was expected but not found.
InvalidEscapeCharacter(SourceSpan)
An invalid escape character was found.
ExpectedExpr(SourceSpan)
An expression was expected in this position but not found.
ExprFoundBinaryOp
A binary operator keyword or sigil was used in a position where an expression was expected.
Filterset binary operators are infix operators, not prefix ones. The
suggest field is the canonical recognized form of the operator, used
to nudge the user toward valid syntax in a single step: for AND it’s
and, for && it’s &, and so on.
Fields
span: SourceSpanThe span of the operator.
ExprFoundUnaryOp
A unary-operator-shaped token was used in a syntax filtersets don’t
recognize, e.g. uppercase NOT instead of not.
The suggest field is the canonical recognized form.
Fields
span: SourceSpanThe span of the token.
ExpectedEndOfExpression(SourceSpan)
The expression was expected to end here but some extra text was found.
NoPackageMatch(SourceSpan)
This matcher didn’t match any packages.
NoGroupMatch(SourceSpan)
This matcher didn’t match any test groups.
NoBinaryIdMatch(SourceSpan)
This matcher didn’t match any binary IDs.
NoBinaryNameMatch(SourceSpan)
This matcher didn’t match any binary names.
InvalidPlatformArgument(SourceSpan)
Expected “host” or “target” for a platform() predicate.
UnsupportedExpression(SourceSpan)
Contained an unsupported expression.
Unknown
An unknown parsing error occurred.